Index: src/full-codegen/x64/full-codegen-x64.cc |
diff --git a/src/full-codegen/x64/full-codegen-x64.cc b/src/full-codegen/x64/full-codegen-x64.cc |
index cf59e66abdcb7aec5469fe61aff43f3c53ef31ff..a61ef84dd65f31847ebebb4df41d08fde34b8941 100644 |
--- a/src/full-codegen/x64/full-codegen-x64.cc |
+++ b/src/full-codegen/x64/full-codegen-x64.cc |
@@ -174,10 +174,10 @@ void FullCodeGenerator::Generate() { |
if (info->scope()->new_target_var() != nullptr) { |
__ Push(rdx); // Preserve new target. |
} |
- if (slots <= FastNewContextStub::kMaximumSlots) { |
- FastNewContextStub stub(isolate(), slots); |
+ if (slots <= FastNewFunctionContextStub::kMaximumSlots) { |
+ FastNewFunctionContextStub stub(isolate(), slots); |
__ CallStub(&stub); |
// Result of FastNewContextStub is always in new space. |
need_write_barrier = false; |
} else { |
__ Push(rdi); |
@@ -174,10 +174,10 @@ void FullCodeGenerator::Generate() { |
__ CallStub(&stub); |
- // Result of FastNewContextStub is always in new space. |
+ // Result of FastNewFunctionContextStub is always in new space. |
need_write_barrier = false; |
} else { |